==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/fe-deploy/project-manager.js <==
/**
 * 项目管理
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Tabs, Tab, TipPanel } from 'ukelli-ui';
import { Call } from 'basic-helper';
import CreateAsset from './create-asset';
import AssetManager from './assets-manager';
import EditProject from './edit-project';
import AuditLog from './audit-log';
import { applyToJoinInProject } from './apis';
var ProjectManager = /** @class */ (function (_super) {
    __extends(ProjectManager, _super);
    function ProjectManager(props) {
        var _this = _super.call(this, props) || this;
        _this.authFilter();
        return _this;
    }
    ProjectManager.prototype.onCreatedAsset = function () {
        this.tabRef._onChangeTab(0);
    };
    ProjectManager.prototype.onUpdateProject = function () {
        this.props.queryProject();
    };
    ProjectManager.prototype.authFilter = function () {
        var username = this.props.username;
        var _a = this.props.getProject(), collaborators = _a.collaborators, founder = _a.founder;
        var collaboratorConfig = collaborators[username] || {};
        this.isFounder = username === founder;
        this.updatable = this.isFounder || collaboratorConfig.updatable;
        this.deletable = this.isFounder || collaboratorConfig.deletable;
        this.releasable = this.isFounder || collaboratorConfig.releasable;
        this.canOperate = this.isFounder || collaborators.hasOwnProperty(username);
    };
    ProjectManager.prototype.applyToJoin = function (projId) {
        return __awaiter(this, void 0, void 0, function () {
            var _a, username, notify, onApplied, applyRes, isSuccess;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this.props, username = _a.username, notify = _a.notify, onApplied = _a.onApplied;
                        return [4 /*yield*/, applyToJoinInProject({ projId: projId, username: username })];
                    case 1:
                        applyRes = _b.sent();
                        isSuccess = !applyRes.err;
                        if (isSuccess) {
                            Call(onApplied);
                        }
                        notify('申请', isSuccess, applyRes.err);
                        return [2 /*return*/];
                }
            });
        });
    };
    ProjectManager.prototype.render = function () {
        var _this = this;
        var targetProject = this.props.getProject() || {};
        var defaultTab = this.props.defaultTab;
        var projId = targetProject.id;
        var _defaultTab = {
            edit: 2,
            'asset-list': 0,
            upload: 1,
        };
        var container = (React.createElement("div", { className: "project-manager p10" },
            !this.canOperate && (React.createElement("div", null,
                React.createElement(TipPanel, { title: "\u4F60\u6682\u65F6\u8FD8\u4E0D\u662F\u8BE5\u9879\u76EE\u7684\u534F\u4F5C\u8005\uFF0C\u53EF\u4EE5\u901A\u8FC7\u7533\u8BF7\u8FDB\u884C\u9879\u76EE\u534F\u4F5C" }),
                React.createElement("div", { className: "text-center" },
                    React.createElement("span", { className: "btn flat theme", onClick: function (e) { return _this.applyToJoin(projId); } }, "\u7533\u8BF7\u52A0\u5165\u534F\u4F5C")))),
            React.createElement(Tabs, { ref: function (e) { return _this.tabRef = e; }, defaultTab: _defaultTab[defaultTab] },
                React.createElement(Tab, { label: "\u8D44\u6E90\u5217\u8868" },
                    React.createElement(AssetManager, __assign({ releasable: this.releasable }, this.props, { projId: projId }))),
                this.updatable && (React.createElement(Tab, { label: "\u4E0A\u4F20\u65B0\u8D44\u6E90" },
                    React.createElement(CreateAsset, __assign({}, this.props, { project: targetProject, projId: projId, onSuccess: function (e) { return _this.onCreatedAsset(); } })))),
                this.updatable && (React.createElement(Tab, { label: "\u9879\u76EE\u7F16\u8F91" },
                    React.createElement(EditProject, __assign({}, this.props, { project: targetProject, onUpdated: function (e) { return _this.onUpdateProject(); } })))),
                this.isFounder && (React.createElement(Tab, { label: "\u64CD\u4F5C\u8BB0\u5F55" },
                    React.createElement(AuditLog, __assign({}, this.props, { projId: projId })))))));
        return container;
    };
    ProjectManager.propTypes = {
        getProject: PropTypes.func.isRequired,
        queryProject: PropTypes.func.isRequired,
        defaultTab: PropTypes.string,
    };
    ProjectManager.defaultProps = {
        defaultTab: '0'
    };
    return ProjectManager;
}(Component));
export default ProjectManager;

==> uke-admin-web-scaffold-1.2.4.tgz: package/fe-deploy/project-manager.js <==
/**
 * 项目管理
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Tabs, Tab, Alert } from 'ukelli-ui';
import { Call } from 'basic-helper';
import CreateAsset from './create-asset';
import AssetManager from './assets-manager';
import EditProject from './edit-project';
import AuditLog from './audit-log';
import { applyToJoinInProject } from './apis';
var ProjectManager = /** @class */ (function (_super) {
    __extends(ProjectManager, _super);
    function ProjectManager(props) {
        var _this = _super.call(this, props) || this;
        _this.authFilter();
        return _this;
    }
    ProjectManager.prototype.onCreatedAsset = function () {
        this.tabRef._onChangeTab(0);
    };
    ProjectManager.prototype.onUpdateProject = function () {
        this.props.queryProject();
    };
    ProjectManager.prototype.authFilter = function () {
        var username = this.props.username;
        var _a = this.props.getProject(), collaborators = _a.collaborators, founder = _a.founder;
        var collaboratorConfig = collaborators[username] || {};
        this.isFounder = username === founder;
        this.updatable = this.isFounder || collaboratorConfig.updatable;
        this.deletable = this.isFounder || collaboratorConfig.deletable;
        this.releasable = this.isFounder || collaboratorConfig.releasable;
        this.canOperate = this.isFounder || collaborators.hasOwnProperty(username);
    };
    ProjectManager.prototype.applyToJoin = function (projId) {
        return __awaiter(this, void 0, void 0, function () {
            var _a, username, notify, onApplied, applyRes, isSuccess;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = this.props, username = _a.username, notify = _a.notify, onApplied = _a.onApplied;
                        return [4 /*yield*/, applyToJoinInProject({ projId: projId, username: username })];
                    case 1:
                        applyRes = _b.sent();
                        isSuccess = !applyRes.err;
                        if (isSuccess) {
                            Call(onApplied);
                        }
                        notify('申请', isSuccess, applyRes.err);
                        return [2 /*return*/];
                }
            });
        });
    };
    ProjectManager.prototype.render = function () {
        var _this = this;
        var targetProject = this.props.getProject() || {};
        var defaultTab = this.props.defaultTab;
        var projId = targetProject.id;
        var _defaultTab = {
            edit: 2,
            'asset-list': 0,
            upload: 1,
        };
        var container = (React.createElement("div", { className: "project-manager p10" },
            !this.canOperate && (React.createElement("div", null,
                React.createElement(Alert, { title: "\u4F60\u6682\u65F6\u8FD8\u4E0D\u662F\u8BE5\u9879\u76EE\u7684\u534F\u4F5C\u8005\uFF0C\u53EF\u4EE5\u901A\u8FC7\u7533\u8BF7\u8FDB\u884C\u9879\u76EE\u534F\u4F5C" }),
                React.createElement("div", { className: "text-center" },
                    React.createElement("span", { className: "btn flat theme", onClick: function (e) { return _this.applyToJoin(projId); } }, "\u7533\u8BF7\u52A0\u5165\u534F\u4F5C")))),
            React.createElement(Tabs, { ref: function (e) { return _this.tabRef = e; }, defaultTab: _defaultTab[defaultTab] },
                React.createElement(Tab, { label: "\u8D44\u6E90\u5217\u8868" },
                    React.createElement(AssetManager, __assign({ releasable: this.releasable }, this.props, { projId: projId }))),
                this.updatable && (React.createElement(Tab, { label: "\u4E0A\u4F20\u65B0\u8D44\u6E90" },
                    React.createElement(CreateAsset, __assign({}, this.props, { project: targetProject, projId: projId, onSuccess: function (e) { return _this.onCreatedAsset(); } })))),
                this.updatable && (React.createElement(Tab, { label: "\u9879\u76EE\u7F16\u8F91" },
                    React.createElement(EditProject, __assign({}, this.props, { project: targetProject, onUpdated: function (e) { return _this.onUpdateProject(); } })))),
                this.isFounder && (React.createElement(Tab, { label: "\u64CD\u4F5C\u8BB0\u5F55" },
                    React.createElement(AuditLog, __assign({}, this.props, { projId: projId })))))));
        return container;
    };
    ProjectManager.propTypes = {
        getProject: PropTypes.func.isRequired,
        queryProject: PropTypes.func.isRequired,
        defaultTab: PropTypes.string,
    };
    ProjectManager.defaultProps = {
        defaultTab: '0'
    };
    return ProjectManager;
}(Component));
export default ProjectManager;
